Version 0.6.2 — Version 0.11.0.dev0

# Version 0.6.2

February 16, 2020

This is a bug-fix release to resolve some issues regarding the handling the input and the output format of the arrays.

## Changelog

- Allow column vectors to be passed as targets. #673 by Christos Aridas.

- Better input/output handling for pandas, numpy and plain lists. #681 by Christos Aridas.

# Version 0.6.1

December 7, 2019

This is a bug-fix release to primarily resolve some packaging issues in version 0.6.0. It also includes minor documentation improvements and some bug fixes.

## Changelog

### Bug fixes

- Fix a bug in `imblearn.ensemble.BalancedRandomForestClassifier` leading to a wrong number of samples used during fitting due `max_samples` and therefore a bad computation of the OOB score. #656 by Guillaume Lemaitre.

# Version 0.6.0

December 5, 2019

## Changelog

### Changed models

The following models might give some different sampling due to changes in scikit-learn:

- `imblearn.under_sampling.ClusterCentroids`

- `imblearn.under_sampling.InstanceHardnessThreshold`

The following samplers will give different results due to change linked to the random state internal usage:

- `imblearn.over_sampling.ADASYN`

- `imblearn.over_sampling.SMOTENC`

### Bug fixes

- `imblearn.under_sampling.InstanceHardnessThreshold` now take into account the `random_state` and will give deterministic results. In addition, `cross_val_predict` is used to take advantage of the parallelism. #599 by Shihab Shahriar Khan.

- Fix a bug in `imblearn.ensemble.BalancedRandomForestClassifier` leading to a wrong computation of the OOB score. #656 by Guillaume Lemaitre.

### Maintenance

- Update imports from scikit-learn after that some modules have been privatize. The following import have been changed: `sklearn.ensemble._base._set_random_states`, `sklearn.ensemble._forest._parallel_build_trees`, `sklearn.metrics._classification._check_targets`, `sklearn.metrics._classification._prf_divide`, `sklearn.utils.Bunch`, `sklearn.utils._safe_indexing`, `sklearn.utils._testing.assert_allclose`, `sklearn.utils._testing.assert_array_equal`, `sklearn.utils._testing.SkipTest`. #617 by Guillaume Lemaitre.

- Synchronize `imblearn.pipeline` with `sklearn.pipeline`. #620 by Guillaume Lemaitre.

- Synchronize `imblearn.ensemble.BalancedRandomForestClassifier` and add parameters `max_samples` and `ccp_alpha`. #621 by Guillaume Lemaitre.

### Enhancement

- `imblearn.under_sampling.RandomUnderSampling`, `imblearn.over_sampling.RandomOverSampling`, `imblearn.datasets.make_imbalance` accepts Pandas DataFrame in and will output Pandas DataFrame. Similarly, it will accepts Pandas Series in and will output Pandas Series. #636 by Guillaume Lemaitre.

- `imblearn.FunctionSampler` accepts a parameter `validate` allowing to check or not the input `X` and `y`. #637 by Guillaume Lemaitre.

- `imblearn.under_sampling.RandomUnderSampler`, `imblearn.over_sampling.RandomOverSampler` can resample when non finite values are present in `X`. #643 by Guillaume Lemaitre.

- All samplers will output a Pandas DataFrame if a Pandas DataFrame was given as an input. #644 by Guillaume Lemaitre.

- The samples generation in `imblearn.over_sampling.ADASYN`, `imblearn.over_sampling.SMOTE`, `imblearn.over_sampling.BorderlineSMOTE`, `imblearn.over_sampling.SVMSMOTE`, `imblearn.over_sampling.KMeansSMOTE`, `imblearn.over_sampling.SMOTENC` is now vectorize with giving an additional speed-up when `X` in sparse. #596 and #649 by Matt Eding.

### Deprecation

- The following classes have been removed after 2 deprecation cycles: `ensemble.BalanceCascade` and `ensemble.EasyEnsemble`. #617 by Guillaume Lemaitre.

- The following functions have been removed after 2 deprecation cycles: `utils.check_ratio`. #617 by Guillaume Lemaitre.

- The parameter `ratio` and `return_indices` has been removed from all samplers. #617 by Guillaume Lemaitre.

- The parameters `m_neighbors`, `out_step`, `kind`, `svm_estimator` have been removed from the `imblearn.over_sampling.SMOTE`. #617 by Guillaume Lemaitre.